@@ -1,19 +1,17 @@
 package CGI::Untaint::date;
 
+$VERSION = '1.00';
+
 use strict;
 use base 'CGI::Untaint::printable';
 use Date::Manip;
 use Date::Simple;
 
-use vars qw/$VERSION/;
-$VERSION = '0.03';
-
-
 sub is_valid {
   my $self = shift;
   local $SIG{__WARN__} = sub {};
   local *Date::Manip::Date_TimeZone = sub { 'GMT' };
-  Date_Init('DateFormat=UK');
+  Date_Init(sprintf 'DateFormat=%s' => $self->date_format);
   my $date = ParseDate($self->value) or return;
   my @date = unpack "A4A2A2", $date;
   my $ds = eval { Date::Simple->new(@date) } or return;
@@ -21,6 +19,7 @@ sub is_valid {
   return $ds;
 }
 
+sub date_format { 'UK' }
 
 =head1 NAME
 
@@ -35,6 +34,8 @@ CGI::Untaint::date - validate a date
 
 =head1 DESCRIPTION
 
+=head2 is_valid
+
 This Input Handler verifies that it is dealing with a reasonable
 date. Reasonably means anything that Date::Manip thinks is
 sensible, so you could use any of (for example):
@@ -44,16 +45,18 @@ sensible, so you could use any of (for example):
   "next Tuesday"
   "third Wednesday in March"
 
-L<Date::Manip> for much more information on what date formats are
+See L<Date::Manip> for much more information on what date formats are
 acceptable.
 
 The resulting date will be a Date::Simple object. 
 L<Date::Simple> for more information on this.
 
-=head1 NOTE
+=head2 date_format
 
-Ambiguous dates of the format 08/09/2001 will be treated
-as UK style (i.e. 9th August, rather than 8th September).
+By default ambiguous dates of the format 08/09/2001 will be treated as
+UK style (i.e. 8th September rather than 9th August)
+
+If you want to change this, subclass it and override date_format()
 
 =head1 WARNING
 
@@ -68,11 +71,16 @@ L<Date::Simple>. L<Date::Manip>.
 
 =head1 AUTHOR
 
-Tony Bowden, E<lt>kasei@tmtm.comE<gt>. 
+Tony Bowden
 
-=head1 COPYRIGHT
+=head1 BUGS and QUERIES
 
-Copyright (C) 2001 Tony Bowden. All rights reserved.
+Please direct all correspondence regarding this module to:
+  bug-CGI-Untaint-date@rt.cpan.org
+
+=head1 COPYRIGHT and LICENSE
+
+Copyright (C) 2001-2005 Tony Bowden. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
